<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:manifest="urn:oasis:names:tc:opendocument:xmlns:manifest:1.0"
  xmlns:dc="http://purl.org/dc/elements/1.1/"
  xmlns="http://www.w3.org/1999/xhtml"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
  exclude-result-prefixes="rdf manifest dc">
  <xsl:output method="xhtml"/>
  <xsl:strip-space elements="*"/>
  <xsl:variable name="odf-metadata" as="element()*">
    <rdf:RDF>
      <xsl:for-each
        select="//manifest:file-entry[@manifest:media-type=&apos;text/xml+rdf&apos;]">
        <xsl:copy-of select="document(concat(&apos;../&apos;,
          @manifest:full-path))/*/*"/>
      </xsl:for-each>
    </rdf:RDF>
  </xsl:variable>
  <xsl:template match="/">
    <html>
      <head>
        <title>Metadata Report</title>
        <style type="text/css"> 
          body { 
          margin: auto; 
          width: 600px; 
          font-family:'Gill Sans', 'Lucida Sans', Verdana; 
          }
          div.resource { border: 1px solid silver; padding: 1em; margin-top: 1em; } 
          table { width: 100%; } 
          p { line-height: 1.5em; }
          h1 { text-align: center; }
          .value { font-style: italic; color: red ;}
          div.note { background: black; color: white; padding: 2em; margin: 2em; }
        </style>
      </head>
      <body>
        <div class="note">
          <p>This demonstration shows just a glimpse of some of the benefits
            that can come from using a standard metadata model like RDF. All of
            the metadata included in the archive is valid RDF. It is also quite
            easy to process with XML tools. This demo document, for example, was
            generated with an XSLT stylesheet which did not include any specific
            property or resource logic. All xpath expressions refer to generic
            characteristics.</p>
        </div>
        <h1>Metadata Report</h1>
        <p>This OpenDocument file contains the following metadata.</p>
        <xsl:for-each select="$odf-metadata/*">
          <div class="resource">
            <h2>
              <xsl:value-of select="local-name(.)"/>
            </h2>
            <ul class="properties">
              <xsl:apply-templates/>
            </ul>
          </div>
        </xsl:for-each>
      </body>
    </html>
  </xsl:template>
  <xsl:template match="rdf:RDF/*">
    <div class="resource">
      <h2>
        <xsl:value-of select="local-name(.)"/>
      </h2>
      <ul class="properties">
        <xsl:apply-templates/>
      </ul>
    </div>
  </xsl:template>
  <xsl:template match="*[not(*) and not(@rdf:resource)]">
    <xsl:call-template name="render-property"/>
  </xsl:template>
  <xsl:template name="render-property">
    <li class="simple-property">
      <span class="property">
        <xsl:value-of select="local-name(.)"/>
        <xsl:text>: </xsl:text>
      </span>
      <span class="value">
        <xsl:value-of select="."/>
      </span>
    </li>
  </xsl:template>
  <xsl:template match="*[* and not(@rdf:about) and not(@rdf:resource)]">
    <li class="blank-node">
      <xsl:choose>
        <xsl:when test="following-sibling::*[text()] or
          preceding-sibling::*[text()]">
          <span class="property">
            <xsl:value-of select="local-name(.)"/>
          </span>
          <ul>
            <xsl:apply-templates/>
          </ul>
        </xsl:when>
        <xsl:otherwise>
          <span class="property">
            <xsl:value-of select="local-name(.)"/>
          </span>
          <ul>
            <xsl:apply-templates/>
          </ul>
        </xsl:otherwise>
      </xsl:choose>
    </li>
  </xsl:template>
  <xsl:template match="*[@rdf:resource]">
    <li class="linked-property">
      <span class="property">
        <xsl:value-of select="local-name(.)"/>
        <xsl:text>: </xsl:text>
      </span>
      <span class="value">
        <xsl:value-of select="@rdf:resource"/>
      </span>
    </li>
  </xsl:template>
</xsl:stylesheet>
